==> haskell-reducers-3.12.4-125-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-reducers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 reducers
version:              3.12.4
visibility:           public
id:                   reducers-3.12.4-INqzXwkxoVnAbwQXmsSW3c
key:                  reducers-3.12.4-INqzXwkxoVnAbwQXmsSW3c
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/reducers/
synopsis:
    Semigroups, specialized containers and a general map/reduce framework

description:
    Semigroups, specialized containers and a general map/reduce framework.

category:             Data, Math, Numerical, Semigroups
abi:                  75267e475f597e99310673d5b2690c43
exposed:              True
exposed-modules:
    Data.Generator Data.Generator.Combinators Data.Semigroup.Alt
    Data.Semigroup.Alternative Data.Semigroup.Applicative
    Data.Semigroup.Apply Data.Semigroup.Generator
    Data.Semigroup.Instances Data.Semigroup.Monad
    Data.Semigroup.MonadPlus Data.Semigroup.Reducer
    Data.Semigroup.Reducer.With Data.Semigroup.Self
    Data.Semigroup.Union

import-dirs:          /usr/lib/ghc-9.0.2/site-local/reducers-3.12.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/reducers-3.12.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-reducers
hs-libraries:         HSreducers-3.12.4-INqzXwkxoVnAbwQXmsSW3c
depends:
    array-0.5.4.0 base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    fingertree-0.1.5.0-Kt24ebVh1SrAycGBZPK0Sg
    hashable-1.4.3.0-HJgArJTlHGmAXC3Ze6Bl1H
    semigroupoids-5.3.7-BftWn5H97bzJapOOv22oR7 text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.19.1-ChULPaPHhwJ2dhnjSGpBLT

haddock-interfaces:   /usr/share/doc/haskell-reducers/html/reducers.haddock
haddock-html:         /usr/share/doc/haskell-reducers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-reducers-3.12.4-141-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-reducers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 reducers
version:              3.12.4
visibility:           public
id:                   reducers-3.12.4-3qNnqNIcZzN6W3Me2AfLsl
key:                  reducers-3.12.4-3qNnqNIcZzN6W3Me2AfLsl
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/reducers/
synopsis:
    Semigroups, specialized containers and a general map/reduce framework

description:
    Semigroups, specialized containers and a general map/reduce framework.

category:             Data, Math, Numerical, Semigroups
abi:                  eeeef4a6cece4cb7f86dedb253bbbc30
exposed:              True
exposed-modules:
    Data.Generator Data.Generator.Combinators Data.Semigroup.Alt
    Data.Semigroup.Alternative Data.Semigroup.Applicative
    Data.Semigroup.Apply Data.Semigroup.Generator
    Data.Semigroup.Instances Data.Semigroup.Monad
    Data.Semigroup.MonadPlus Data.Semigroup.Reducer
    Data.Semigroup.Reducer.With Data.Semigroup.Self
    Data.Semigroup.Union

import-dirs:          /usr/lib/ghc-9.0.2/site-local/reducers-3.12.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/reducers-3.12.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-reducers
hs-libraries:         HSreducers-3.12.4-3qNnqNIcZzN6W3Me2AfLsl
depends:
    array-0.5.4.0 base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    fingertree-0.1.5.0-82mxSFKVcEuKnEbT5RffJP
    hashable-1.4.3.0-GjMDKgDyLuqLq9SaBPRy7H
    semigroupoids-5.3.7-4StabZ4oK3bKyXxZVeM2FQ text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-GD5h4dXRiYp4CZJcEpki1R

haddock-interfaces:   /usr/share/doc/haskell-reducers/html/reducers.haddock
haddock-html:         /usr/share/doc/haskell-reducers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
